@@ -1,5 +1,7 @@
 package Calendar::Persian;
 
+$Calendar::Persian::VERSION = '0.09';
+
 use strict; use warnings;
 
 =head1 NAME
@@ -8,53 +10,40 @@ Calendar::Persian - Interface to Persian Calendar.
 
 =head1 VERSION
 
-Version 0.08
+Version 0.09
 
 =cut
 
-our $DEBUG   = 0;
-our $VERSION = '0.08';
+our $DEBUG = 0;
 
-use Carp;
-use Readonly;
 use Data::Dumper;
 use Time::localtime;
 use POSIX qw/floor ceil/;
 use Date::Calc qw/Delta_Days Day_of_Week Add_Delta_Days/;
 
-Readonly my $GREGORIAN_EPOCH => 1721425.5;
-Readonly my $PERSIAN_EPOCH   => 1948320.5;
+my $GREGORIAN_EPOCH = 1721425.5;
+my $PERSIAN_EPOCH   = 1948320.5;
 
-Readonly my $MONTHS =>
-[
+my $MONTHS = [
     '',
     'Farvardin',  'Ordibehesht',  'Khordad',  'Tir',  'Mordad',  'Shahrivar',
-    'Mehr'     ,  'Aban'       ,  'Azar'   ,  'Dey',  'Bahman',  'Esfand'
-];
+    'Mehr'     ,  'Aban'       ,  'Azar'   ,  'Dey',  'Bahman',  'Esfand' ];
 
-Readonly my $DAYS =>
-[
+my $DAYS = [
     'Yekshanbeh',  'Doshanbeh', 'Seshhanbeh', 'Chaharshanbeh',
-    'Panjshanbeh', 'Jomeh',     'Shanbeh'
-];
+    'Panjshanbeh', 'Jomeh',     'Shanbeh' ];
+
+sub new {
+    my ($class, $yyyy, $mm, $dd) = @_;
 
-sub new 
-{
-    my $class = shift;
-    my $yyyy  = shift;
-    my $mm    = shift;
-    my $dd    = shift;
-    
     my $self  = {};
     bless $self, $class;
-    
-    if (defined($yyyy) && defined($mm) && defined($dd))
-    {
+
+    if (defined($yyyy) && defined($mm) && defined($dd)) {
         _validate_date($yyyy, $mm, $dd)
     }
-    else
-    {
-        my $today = localtime; 
+    else {
+        my $today = localtime;
         $yyyy = ($today->year+1900) unless defined $yyyy;
         $mm = ($today->mon+1) unless defined $mm;
         $dd = $today->mday unless defined $dd;
@@ -70,14 +59,17 @@ sub new
 
 =head1 DESCRIPTION
 
-The Persian calendar is solar, with the particularity that the year defined by two successive,
-apparent  passages   of  the  Sun  through the vernal (spring) equinox. It is based on precise 
-astronomical observations, and moreover uses a sophisticated intercalation system, which makes 
-it more accurate than its younger European counterpart,the Gregorian calendar. It is currently 
-used in Iran as the official calendar of the country.The starting point of the current Iranian 
-calendar is the vernal equinox occurred on Friday March 22 of the year A.D. 622. 
+The Persian  calendar  is  solar, with the particularity that the year defined by
+two  successive,  apparent  passages    of  the  Sun  through the vernal (spring)
+equinox.  It  is based  on precise astronomical observations, and moreover uses a
+sophisticated intercalation system, which makes it more accurate than its younger
+European  counterpart,the Gregorian calendar. It is currently used in Iran as the
+official  calendar  of  the  country. The  starting  point of the current Iranian
+calendar is  the  vernal equinox occurred on Friday March 22 of the year A.D. 622.
 Persian Calendar for the month of Farvadin year 1390.
 
+=head1 Persian Calendar for the month of Farvadin year 1390.
+
             Farvardin [1390]
 
     Sun  Mon  Tue  Wed  Thu  Fri  Sat
@@ -89,56 +81,46 @@ Persian Calendar for the month of Farvadin year 1390.
 
 =head1 MONTHS
 
-    +-------+--------------+
-    | Order | Persian Name |
-    +-------+--------------+
-    |  1    | Farvardin    |
-    |  2    | Ordibehesht  |
-    |  3    | Xordad       | 
-    |  4    | Tir          |
-    |  5    | Amordad      |
-    |  6    | Sahrivar     | 
-    |  7    | Mehr         | 
-    |  8    | Aban         |
-    |  9    | Azar         |
-    | 10    | Dey          |
-    | 11    | Bahman       |
-    | 12    | Esfand       |  
-    +-------+--------------+
+    Order     Modern Persian Name
+    1         Farvardin
+    2         Ordibehesht
+    3         Xordad
+    4         Tir
+    5         Amordad
+    6         Sahrivar
+    7         Mehr
+    8         Aban
+    9         Azar
+    10        Dey
+    11        Bahman
+    12        Esfand
 
 =head1 WEEKDAYS
 
-    +------------------------------------+
-    | Number | Gregorian | Persian       |
-    +--------+-----------+---------------+
-    |    0   | Sunday    | Yekshanbeh    |
-    |    1   | Monday    | Doshanbeh     |  
-    |    2   | Tuesday   | Seshhanbeh    |
-    |    3   | Wednesday | Chaharshanbeh |
-    |    4   | Thursday  | Panjshanbeh   |
-    |    5   | Friday    | Jomeh         |
-    |    6   | Saturday  | Shanbeh       |
-    +--------+-----------+---------------+
+    Number   Gregorian    Persian
+    0        Sunday       Yekshanbeh
+    1        Monday       Doshanbeh
+    2        Tuesday      Seshhanbeh
+    3        Wednesday    Chaharshanbeh
+    4        Thursday     Panjshanbeh
+    5        Friday       Jomeh
+    6        Saturday     Shanbeh
 
 =head1 METHODS
 
-=head2 to_gregorian()
+=head2 to_gregorian(yyyy, mm, dd)
 
 Converts Persian date to Gregorian date.
 
     use Calendar::Persian;
 
-    my $calendar = Calendar::Persian->new();
-    my ($yyyy, $mm, $dd) = $calendar->to_gregorian();
+    my $persian = Calendar::Persian->new();
+    my ($yyyy, $mm, $dd) = $persian->to_gregorian();
 
 =cut
 
-sub to_gregorian
-{
-    my $self = shift;
-    my $yyyy = shift;
-    my $mm   = shift;
-    my $dd   = shift;
+sub to_gregorian {
+    my ($self, $yyyy, $mm, $dd) = @_;
 
     $yyyy = $self->{yyyy} unless defined $yyyy;
     $mm   = $self->{mm}   unless defined $mm;
@@ -149,30 +131,26 @@ sub to_gregorian
     print {*STDOUT} "Persian: YYYY [$yyyy] MM [$mm] DD [$dd]\n" if $DEBUG;
 
     my $julian = _to_julian($yyyy, $mm, $dd);
-    ($yyyy, $mm, $dd) =  _julian_to_gregorian($julian); 
+    ($yyyy, $mm, $dd) =  _julian_to_gregorian($julian);
 
     print {*STDOUT} "Gregorian: YYYY [$yyyy] MM [$mm] DD [$dd]\n" if $DEBUG;
 
     return ($yyyy, $mm, $dd);
 }
 
-=head2 from_gregorian()
+=head2 from_gregorian(yyyy, mm, dd)
 
 Converts given Gregorian date to Persian date.
 
     use Calendar::Persian;
 
-    my $calendar = Calendar::Persian->new();
-    my ($yyyy, $mm, $dd) = $calendar->from_gregorian(2011, 3, 22);
+    my $persian = Calendar::Persian->new();
+    my ($yyyy, $mm, $dd) = $persian->from_gregorian(2011, 3, 22);
 
 =cut
 
-sub from_gregorian
-{
-    my $self = shift;
-    my $yyyy = shift;
-    my $mm   = shift;
-    my $dd   = shift;
+sub from_gregorian {
+    my ($self, $yyyy, $mm, $dd) = @_;
 
     _validate_date($yyyy, $mm, $dd);
 
@@ -187,22 +165,20 @@ sub from_gregorian
     return ($yyyy, $mm, $dd);
 }
 
-=head2 is_leap()
+=head2 is_leap(yyyy)
 
-Checks if the given year in Persian calendar is a leap  year  or not. Returns 1 or 0 depending
-whether it is a leap year or not.
+Checks if the given year in Persian calendar is a leap year or not. Return 1 or 0
+depending whether it is a leap year or not.
 
     use Calendar::Persian;
 
-    my $calendar = Calendar::Persian->new();
-    my $is_leap_year = $calendar->is_leap(1389);
+    my $persian = Calendar::Persian->new();
+    my $is_leap_year = $persian->is_leap(1389);
 
 =cut
 
-sub is_leap
-{
-    my $self = shift;
-    my $yyyy = shift;
+sub is_leap {
+    my ($self, $yyyy) = @_;
 
     return (((((($yyyy - (($yyyy > 0) ? 474 : 473)) % 2820) + 474) + 38) * 682) % 2816) < 682;
 }
@@ -214,36 +190,31 @@ Return Persian date in human readable format.
     use strict; use warnings;
     use Calendar::Persian;
 
-    my $calendar = Calendar::Persian->new(1389, 9, 16);
-    print "Persian date is " . $calendar->as_string() . "\n";
+    my $persian = Calendar::Persian->new(1389, 9, 16);
+    print "Persian date is " . $persian->as_string() . "\n";
 
 =cut
 
-sub as_string
-{
-    my $self = shift;
+sub as_string {
+    my ($self) = @_;
+
     return sprintf("%02d, %s %04d", $self->{dd}, $MONTHS->[$self->{mm}], $self->{yyyy});
 }
 
-=head2 dow()
+=head2 dow(yyyy, mm, dd)
 
 Get day of the week of the given Persian date, starting with sunday (0).
 
     use strict; use warnings;
     use Calendar::Persian;
 
-    my $calendar = Calendar::Persian->new();
-    print "Day of the week; [" . $calendar->dow() . "]\n";
+    my $persian = Calendar::Persian->new();
+    print "Day of the week; [" . $persian->dow() . "]\n";
 
 =cut
 
-sub dow
-{
-    my $self = shift;
-
-    my $yyyy = shift;
-    my $mm   = shift;
-    my $dd   = shift;
+sub dow {
+    my ($self, $yyyy, $mm, $dd) = @_;
 
     $yyyy = $self->{yyyy} unless defined $yyyy;
     $mm   = $self->{mm}   unless defined $mm;
@@ -261,16 +232,16 @@ Return today's date is Persian calendar as list in the format yyyy,mm,dd.
     use strict; use warnings;
     use Calendar::Persian;
 
-    my $calendar = Calendar::Persian->new();
-    my ($yyyy, $mm, $dd) = $calendar->today();
+    my $persian = Calendar::Persian->new();
+    my ($yyyy, $mm, $dd) = $persian->today();
     print "Year [$yyyy] Month [$mm] Day [$dd]\n";
 
 =cut
 
-sub today
-{
-    my $self  = shift;
-    my $today = localtime; 
+sub today {
+    my ($self) = @_;
+
+    my $today = localtime;
     return $self->from_gregorian($today->year+1900, $today->mon+1, $today->mday);
 }
 
@@ -287,11 +258,8 @@ Return number of days in the given year and month of Persian calendar.
 
 =cut
 
-sub days_in_month
-{
-    my $self = shift;
-    my $yyyy = shift;
-    my $mm   = shift;
+sub days_in_month {
+    my ($self, $yyyy, $mm) = @_;
 
     $yyyy = $self->{yyyy} unless defined $yyyy;
     $mm   = $self->{mm}   unless defined $mm;
@@ -300,24 +268,23 @@ sub days_in_month
 
     my (@start, @end);
     @start = $self->to_gregorian($yyyy, $mm, 1);
-    if ($mm == 12)
-    {
+    if ($mm == 12) {
         $yyyy += 1;
         $mm    = 1;
     }
-    else
-    {
+    else {
         $mm += 1;
     }
+
     @end = $self->to_gregorian($yyyy, $mm, 1);
 
     return Delta_Days(@start, @end);
 }
 
-=head2 get_calendar()
+=head2 get_calendar(yyyy, mm)
 
-Return calendar for given year & month in Persian calendar. It return current month of Persian
-calendar if no argument is passed in.
+Return  calendar  for given year and month in Persian calendar. It return current
+month of Persian calendar if no argument is passed in.
 
     use strict; use warnings;
     use Calendar::Persian;
@@ -330,11 +297,8 @@ calendar if no argument is passed in.
 
 =cut
 
-sub get_calendar
-{
-    my $self = shift;
-    my $yyyy = shift;    
-    my $mm   = shift;
+sub get_calendar {
+    my ($self, $yyyy, $mm) = @_;
 
     $yyyy = $self->{yyyy} unless defined $yyyy;
     $mm   = $self->{mm} unless defined $mm;
@@ -348,11 +312,11 @@ sub get_calendar
     $start_index = $self->dow($yyyy, $mm, 1);
     $days = $self->days_in_month($yyyy, $mm);
     map { $calendar .= "     " } (1..($start_index%=7));
-    foreach (1 .. $days) 
-    {
+    foreach (1 .. $days) {
         $calendar .= sprintf("%3d  ", $_);
         $calendar .= "\n" unless (($start_index+$_)%7);
     }
+
     return sprintf("%s\n\n", $calendar);
 }
 
@@ -362,39 +326,33 @@ Turn the DEBUG on/off by passing 1/0 respectively.
 
     use Calendar::Persian;
 
-    my $calendar = Calendar::Persian->new();
-    $calendar->debug(1);
+    my $persian = Calendar::Persian->new();
+    $persian->debug(1);
 
 =cut
 
-sub debug
-{
-    my $self = shift;
-    my $flag = shift;
-    croak("ERROR: Invalid value for DEBUG.\n")
-        unless ($flag =~ /^[0|1]$/);
+sub debug {
+    my ($self, $flag) = @_;
+
+    die("ERROR: Invalid value for DEBUG.\n") unless ($flag =~ /^[0|1]$/);
     $DEBUG = $flag;
 }
 
-sub _julian_dow
-{
-    my $julian = shift;
+sub _julian_dow {
+    my ($julian) = @_;
+
     return floor(($julian + 1.5)) % 7;
 }
 
-sub _is_gregorian_leap
-{
-    my $yyyy = shift;
+sub _is_gregorian_leap {
+    my ($yyyy) = @_;
 
     return (($yyyy % 4) == 0) &&
             (!((($yyyy % 100) == 0) && (($yyyy % 400) != 0)));
 }
 
-sub _gregorian_to_julian
-{
-    my $yyyy = shift;
-    my $mm   = shift;
-    my $dd   = shift;
+sub _gregorian_to_julian {
+    my ($yyyy, $mm, $dd) = @_;
 
     return ($GREGORIAN_EPOCH - 1) +
            (365 * ($yyyy - 1)) +
@@ -406,9 +364,8 @@ sub _gregorian_to_julian
            $dd);
 }
 
-sub _julian_to_gregorian
-{
-    my $julian = shift;
+sub _julian_to_gregorian {
+    my ($julian) = @_;
 
     my $wjd        = floor($julian - 0.5) + 0.5;
     my $depoch     = $wjd - $GREGORIAN_EPOCH;
@@ -431,76 +388,68 @@ sub _julian_to_gregorian
     return ($year, $month, $day);
 }
 
-sub _to_julian
-{
-    my $yyyy = shift;
-    my $mm   = shift;
-    my $dd   = shift;
+sub _to_julian {
+    my ($yyyy, $mm, $dd) = @_;
 
     my $epbase = $yyyy - (($yyyy >= 0) ? 474 : 473);
     my $epyear = 474 + ($epbase % 2820);
 
-    return $dd 
+    return $dd
            +
-           (($mm <= 7) 
+           (($mm <= 7)
              ?
-             (($mm - 1) * 31) 
+             (($mm - 1) * 31)
              :
              ((($mm - 1) * 30) + 6)
-           ) 
+           )
            +
-           floor((($epyear * 682) - 110) / 2816) 
+           floor((($epyear * 682) - 110) / 2816)
            +
-           ($epyear - 1) * 365 
+           ($epyear - 1) * 365
            +
-           floor($epbase / 2820) * 1029983 
+           floor($epbase / 2820) * 1029983
            +
            ($PERSIAN_EPOCH - 1);
 }
 
-sub _from_julian
-{
-    my $julian = shift;
-    
+sub _from_julian {
+    my ($julian) = @_;
+
     $julian = floor($julian) + 0.5;
     my $depoch = $julian - _to_julian(475, 1, 1);
     my $cycle  = floor($depoch / 1029983);
     my $cyear  = $depoch % 1029983;
-    
+
     my $ycycle;
-    if ($cyear == 1029982) 
-    {
+    if ($cyear == 1029982) {
         $ycycle = 2820;
-    } 
-    else 
-    {
+    }
+    else {
         my $aux1 = floor($cyear / 366);
         my $aux2 = $cyear % 366;
         $ycycle = floor(((2134 * $aux1) + (2816 * $aux2) + 2815) / 1028522) + $aux1 + 1;
     }
+
     my $yyyy = $ycycle + (2820 * $cycle) + 474;
-    if ($yyyy <= 0) 
-    {
+    if ($yyyy <= 0) {
         $yyyy--;
     }
+
     my $yday = ($julian - _to_julian($yyyy, 1, 1)) + 1;
     my $mm   = ($yday <= 186) ? ceil($yday / 31) : ceil(($yday - 6) / 30);
     my $dd   = ($julian - _to_julian($yyyy, $mm, 1)) + 1;
-    
+
     return ($yyyy, $mm, $dd);
 }
 
-sub _validate_date
-{
-    my $yyyy = shift;
-    my $mm   = shift;
-    my $dd   = shift;
+sub _validate_date {
+    my ($yyyy, $mm, $dd) = @_;
 
-    croak("ERROR: Invalid year [$yyyy].\n")
+    die("ERROR: Invalid year [$yyyy].\n")
         unless (defined($yyyy) && ($yyyy =~ /^\d{4}$/) && ($yyyy > 0));
-    croak("ERROR: Invalid month [$mm].\n")
+    die("ERROR: Invalid month [$mm].\n")
         unless (defined($mm) && ($mm =~ /^\d{1,2}$/) && ($mm >= 1) && ($mm <= 12));
-    croak("ERROR: Invalid day [$dd].\n")
+    die("ERROR: Invalid day [$dd].\n")
         unless (defined($dd) && ($dd =~ /^\d{1,2}$/) && ($dd >= 1) && ($dd <= 31));
 }
 
@@ -508,12 +457,16 @@ sub _validate_date
 
 Mohammad S Anwar, C<< <mohammad.anwar at yahoo.com> >>
 
+=head1 REPOSITORY
+
+L<https://github.com/Manwar/Calendar-Persian>
+
 =head1 BUGS
 
-Please report any bugs/feature requests to C<bug-calendar-persian at rt.cpan.org>,  or through
-the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Calendar-Persian>.  
-I will be notified and then you'll automatically be notified of progress on your bug as I make 
-changes.
+Please report any bugs or feature requests to C<bug-calendar-persian at rt.cpan.org>,
+or through the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Calendar-Persian>.
+I will be notified, and then you'll automatically be notified of progress on your
+bug as I make changes.
 
 =head1 SUPPORT
 
@@ -545,19 +498,42 @@ L<http://search.cpan.org/dist/Calendar-Persian/>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2011 Mohammad S Anwar.
+Copyright 2011 - 2014 Mohammad S Anwar.
 
-This  program  is  free software;  you can redistribute it and/or modify it under the terms of
-either:  the  GNU  General Public License as published by the Free Software Foundation; or the
-Artistic License.
+This  program  is  free software; you can redistribute it and/or modify it under
+the  terms  of the the Artistic License (2.0). You may obtain a copy of the full
+license at:
 
-See http://dev.perl.org/licenses/ for more information.
+L<http://www.perlfoundation.org/artistic_license_2_0>
 
-=head1 DISCLAIMER
+Any  use,  modification, and distribution of the Standard or Modified Versions is
+governed by this Artistic License.By using, modifying or distributing the Package,
+you accept this license. Do not use, modify, or distribute the Package, if you do
+not accept this license.
 
-This  program  is  distributed  in  the hope that it will be useful, but WITHOUT ANY WARRANTY; 
-without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+If your Modified Version has been derived from a Modified Version made by someone
+other than you,you are nevertheless required to ensure that your Modified Version
+ complies with the requirements of this license.
+
+This  license  does  not grant you the right to use any trademark,  service mark,
+tradename, or logo of the Copyright Holder.
+
+This license includes the non-exclusive, worldwide, free-of-charge patent license
+to make,  have made, use,  offer to sell, sell, import and otherwise transfer the
+Package with respect to any patent claims licensable by the Copyright Holder that
+are  necessarily  infringed  by  the  Package. If you institute patent litigation
+(including  a  cross-claim  or  counterclaim) against any party alleging that the
+Package constitutes direct or contributory patent infringement,then this Artistic
+License to you shall terminate on the date that such litigation is filed.
+
+Disclaimer  of  Warranty:  THE  PACKAGE  IS  PROVIDED BY THE COPYRIGHT HOLDER AND
+CONTRIBUTORS  "AS IS'  AND WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES. THE IMPLIED
+WARRANTIES    OF   MERCHANTABILITY,   FITNESS   FOR   A   PARTICULAR  PURPOSE, OR
+NON-INFRINGEMENT ARE DISCLAIMED TO THE EXTENT PERMITTED BY YOUR LOCAL LAW. UNLESS
+REQUIRED BY LAW, NO COPYRIGHT HOLDER OR CONTRIBUTOR WILL BE LIABLE FOR ANY DIRECT,
+INDIRECT, INCIDENTAL,  OR CONSEQUENTIAL DAMAGES ARISING IN ANY WAY OUT OF THE USE
+OF THE PACKAGE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 =cut
 
-1; # End of Calendar::Persian
\ No newline at end of file
+1; # End of Calendar::Persian
